@@ -1,7 +1,7 @@
 package Acme::CPANModules::PERLANCAR::Avoided;
 
-our $DATE = '2019-01-09'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2020-07-21'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 our $LIST = {
     summary => "Modules I'm currently avoiding",
@@ -134,6 +134,15 @@ file, and find all matches instead of the first.
 _
             alternate_modules => ['Module::Path::More'],
         },
+        {
+            module => 'String::Truncate',
+            description => <<'_',
+
+Has non-core dependencies to <pm:Sub::Exporter> and <pm:Sub::Install>.
+
+_
+            alternate_modules => ['String::Elide::Tiny'],
+        },
     ],
 };
 
@@ -152,12 +161,10 @@ Acme::CPANModules::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::PERLANCAR::Avoided (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2019-01-09.
+This document describes version 0.006 of Acme::CPANModules::PERLANCAR::Avoided (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2020-07-21.
 
 =head1 DESCRIPTION
 
-Modules I'm currently avoiding.
-
 This is a list of modules I'm currently avoiding to use in my code, for some
 reason. Most of the modules wered used in my code in the past.
 
@@ -262,8 +269,32 @@ file, and find all matches instead of the first.
 
 Alternate modules: L<Module::Path::More>
 
+=item * L<String::Truncate>
+
+Has non-core dependencies to L<Sub::Exporter> and L<Sub::Install>.
+
+
+Alternate modules: L<String::Elide::Tiny>
+
 =back
 
+=head1 FAQ
+
+=head2 What are ways to use this module?
+
+Aside from reading it, you can install all the listed modules using
+L<cpanmodules>:
+
+    % cpanmodules ls-entries PERLANCAR::Avoided | cpanm -n
+
+or L<Acme::CM::Get>:
+
+    % perl -MAcme::CM::Get=PERLANCAR::Avoided -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
+
+This module also helps L<lcpan> produce a more meaningful result for C<lcpan
+related-mods> when it comes to finding related modules for the modules listed
+in this Acme::CPANModules module.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-PERLANCAR>.
@@ -292,7 +323,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
