@@ -1,7 +1,7 @@
 package Acme::CPANModules::PERLANCAR::MyGetoptLongExperiment;
 
-our $DATE = '2019-01-09'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2020-07-21'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 our $LIST = {
     summary => 'My experiments writing Getopt::Long replacements/alternatives',
@@ -38,12 +38,10 @@ Acme::CPANModules::PERLANCAR::MyGetoptLongExperiment - My experiments writing Ge
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::PERLANCAR::MyGetoptLongExperiment (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2019-01-09.
+This document describes version 0.006 of Acme::CPANModules::PERLANCAR::MyGetoptLongExperiment (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2020-07-21.
 
 =head1 DESCRIPTION
 
-My experiments writing Getopt::Long replacements/alternatives.
-
 Most of these modules provide a L<Getopt::Long>-compatible interface, but they
 differ in some aspect: either they offer more features (or less).
 
@@ -65,6 +63,23 @@ differ in some aspect: either they offer more features (or less).
 
 =back
 
+=head1 FAQ
+
+=head2 What are ways to use this module?
+
+Aside from reading it, you can install all the listed modules using
+L<cpanmodules>:
+
+    % cpanmodules ls-entries PERLANCAR::MyGetoptLongExperiment | cpanm -n
+
+or L<Acme::CM::Get>:
+
+    % perl -MAcme::CM::Get=PERLANCAR::MyGetoptLongExperiment -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
+
+This module also helps L<lcpan> produce a more meaningful result for C<lcpan
+related-mods> when it comes to finding related modules for the modules listed
+in this Acme::CPANModules module.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-PERLANCAR>.
@@ -93,7 +108,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
