@@ -1,7 +1,7 @@
 package Acme::CPANModules::PERLANCAR::Retired;
 
-our $DATE = '2019-01-09'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2020-07-21'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 our $LIST = {
     summary => 'Retired modules',
@@ -111,12 +111,10 @@ Acme::CPANModules::PERLANCAR::Retired - Retired modules
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::PERLANCAR::Retired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2019-01-09.
+This document describes version 0.006 of Acme::CPANModules::PERLANCAR::Retired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2020-07-21.
 
 =head1 DESCRIPTION
 
-Retired modules.
-
 This is a list of some of the modules which I wrote but have now been retired
 and purged from CPAN, for various reasons but mostly because they are no longer
 necessary. I've purged/retired more modules than these (mostly failed
@@ -189,6 +187,23 @@ Alternate modules: L<Package::Stash>, L<Package::Util::Lite>
 
 =back
 
+=head1 FAQ
+
+=head2 What are ways to use this module?
+
+Aside from reading it, you can install all the listed modules using
+L<cpanmodules>:
+
+    % cpanmodules ls-entries PERLANCAR::Retired | cpanm -n
+
+or L<Acme::CM::Get>:
+
+    % perl -MAcme::CM::Get=PERLANCAR::Retired -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
+
+This module also helps L<lcpan> produce a more meaningful result for C<lcpan
+related-mods> when it comes to finding related modules for the modules listed
+in this Acme::CPANModules module.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-PERLANCAR>.
@@ -217,7 +232,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
